import React from 'react';
import cn from 'classnames';
import { IconButton } from '@alfalab/core-components-icon-button/esm';
import { Link } from '@alfalab/core-components-link/esm';
import { Spinner } from '@alfalab/core-components-spinner/esm';
import { AlertCircleMIcon } from '@alfalab/icons-glyph/AlertCircleMIcon';
import { CheckmarkCircleMIcon } from '@alfalab/icons-glyph/CheckmarkCircleMIcon';
import { ClockMIcon } from '@alfalab/icons-glyph/ClockMIcon';
import { CrossSIcon } from '@alfalab/icons-glyph/CrossSIcon';
import { PointerDownSIcon } from '@alfalab/icons-glyph/PointerDownSIcon';
import { fileIcon, humanFileSize } from './utils.js';

var styles = {"component":"file-upload-item__component_8sw4y","infoSection":"file-upload-item__infoSection_8sw4y","info":"file-upload-item__info_8sw4y","icon":"file-upload-item__icon_8sw4y","errorIcon":"file-upload-item__errorIcon_8sw4y","successIcon":"file-upload-item__successIcon_8sw4y","name":"file-upload-item__name_8sw4y","rowLimit":"file-upload-item__rowLimit_8sw4y","meta":"file-upload-item__meta_8sw4y","size":"file-upload-item__size_8sw4y","delete":"file-upload-item__delete_8sw4y","download":"file-upload-item__download_8sw4y","errorWrapper":"file-upload-item__errorWrapper_8sw4y","restore":"file-upload-item__restore_8sw4y","spinnerWrapper":"file-upload-item__spinnerWrapper_8sw4y","spinner":"file-upload-item__spinner_8sw4y","uploadPercent":"file-upload-item__uploadPercent_8sw4y"};
require('./index.css')

var FileUploadItem = function (_a) {
    var className = _a.className, children = _a.children, _b = _a.id, id = _b === void 0 ? '0' : _b, _c = _a.name, name = _c === void 0 ? '' : _c, size = _a.size, _d = _a.icon, Icon = _d === void 0 ? fileIcon(name) : _d, uploadDate = _a.uploadDate, downloadLink = _a.downloadLink, download = _a.download, uploadStatus = _a.uploadStatus, _e = _a.uploadPercent, uploadPercent = _e === void 0 ? 0 : _e, error = _a.error, showDelete = _a.showDelete, showRestore = _a.showRestore, onDelete = _a.onDelete, onDownload = _a.onDownload, onRestore = _a.onRestore, disableButtons = _a.disableButtons, _f = _a.multiline, multiline = _f === void 0 ? false : _f, target = _a.target, dataTestId = _a.dataTestId;
    var handleDownload = function (event) {
        if (onDownload) {
            event.preventDefault();
            onDownload(id);
        }
    };
    var handleDelete = function (event) {
        if (onDelete)
            onDelete(id, event);
    };
    var handleRestore = function () {
        if (onRestore)
            onRestore(id);
    };
    var renderIcon = function () {
        if (showRestore) {
            return React.createElement(ClockMIcon, { className: styles.restoreIcon });
        }
        switch (uploadStatus) {
            case 'ERROR':
                return React.createElement(AlertCircleMIcon, { className: styles.errorIcon });
            case 'SUCCESS':
                return React.createElement(CheckmarkCircleMIcon, { className: styles.successIcon });
            case 'LOADING':
            case 'UPLOADING':
                return (React.createElement("div", { className: styles.spinnerWrapper },
                    React.createElement(Spinner, { visible: true, className: styles.spinner })));
            default: {
                return React.createElement(Icon, { className: styles.icon });
            }
        }
    };
    var renderInfoSection = function () {
        var _a;
        var shouldShownError = uploadStatus === 'ERROR' || !!error;
        var errorContent = uploadStatus === 'ERROR' && !error ? 'Не удалось загрузить файл' : error;
        return (React.createElement("div", { className: styles.infoSection },
            React.createElement("div", { className: cn(styles.name, (_a = {}, _a[styles.rowLimit] = !multiline, _a)) }, name),
            shouldShownError && (React.createElement("div", { className: styles.errorWrapper, role: 'alert' }, errorContent))));
    };
    var showMeta = !showRestore && (!uploadStatus || uploadStatus === 'SUCCESS');
    var showDownload = Boolean(downloadLink) && !showRestore;
    return (React.createElement("div", { className: cn(className, styles.component, uploadStatus && styles[uploadStatus.toLocaleLowerCase()]), "data-test-id": dataTestId },
        React.createElement("div", { className: styles.info },
            renderIcon(),
            renderInfoSection(),
            children,
            uploadStatus === 'UPLOADING' && (React.createElement("span", { className: styles.uploadPercent }, "".concat(Math.round(uploadPercent), "%"))),
            showMeta && (React.createElement("div", { className: styles.meta },
                uploadDate && React.createElement("span", { key: uploadDate }, uploadDate),
                size && (React.createElement("span", { key: size, className: styles.size }, humanFileSize(size)))))),
        showRestore && (React.createElement(Link, { pseudo: true, className: styles.restore, onClick: handleRestore }, "\u0412\u043E\u0441\u0441\u0442\u0430\u043D\u043E\u0432\u0438\u0442\u044C")),
        showDownload && (React.createElement(IconButton, { size: 'xxs', icon: PointerDownSIcon, className: styles.download, "aria-label": '\u0441\u043A\u0430\u0447\u0430\u0442\u044C', href: downloadLink, onClick: handleDownload, disabled: disableButtons, download: download, target: target })),
        showDelete && !showRestore && (React.createElement(IconButton, { size: 'xxs', icon: CrossSIcon, onClick: handleDelete, disabled: disableButtons, className: styles.delete, "aria-label": '\u0443\u0434\u0430\u043B\u0438\u0442\u044C' }))));
};

export { FileUploadItem };
